@@ -7,7 +7,7 @@ from firesvm.kernels import *
 class SVM:
     def __init__(self, kernel=rbf, C=None, tol = 1e-5, max_iter = 100, verbose = False):
         self.kernel = kernel
-        if self.C is not None : self.C = C
+        self.C = C
         self.tol = tol
         self.max_iter = max_iter
         self.verbose = verbose
